constrainttools.Domain
======================

.. inheritance-diagram:: abjad.tools.constrainttools.Domain.Domain.Domain
   :private-bases:

.. autoclass:: abjad.tools.constrainttools.Domain.Domain.Domain

Methods
-------

.. automethod:: abjad.tools.constrainttools.Domain.Domain.Domain.randomized

Special Methods
---------------

.. automethod:: abjad.tools.constrainttools.Domain.Domain.Domain.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.constrainttools.Domain.Domain.Domain.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.constrainttools.Domain.Domain.Domain.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.constrainttools.Domain.Domain.Domain.__getitem__

.. automethod:: abjad.tools.constrainttools.Domain.Domain.Domain.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.constrainttools.Domain.Domain.Domain.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.constrainttools.Domain.Domain.Domain.__iter__

.. automethod:: abjad.tools.constrainttools.Domain.Domain.Domain.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.constrainttools.Domain.Domain.Domain.__len__

.. automethod:: abjad.tools.constrainttools.Domain.Domain.Domain.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.constrainttools.Domain.Domain.Domain.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.constrainttools.Domain.Domain.Domain.__repr__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.constrainttools.Domain.Domain.Domain.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.constrainttools.Domain.Domain.Domain.__str__

   .. note:: Inherited from `__builtin__.object`
